# Specialized NIMs

> Domain-specific inference microservices for biology, medicine, climate, and simulation.

## Canonical URL

`https://docs.nvidia.com/nim/index.html`

## BioNeMo (Biology & Drug Discovery)

NIMs for protein structure prediction, molecular design, and drug discovery.

| Model | Description |
|---|---|
| **AlphaFold2** | Protein structure prediction |
| **Boltz2** | Biomolecular structure prediction |
| **OpenFold2/3** | Open-source protein folding |
| **ProteinMPNN** | Protein sequence design |
| **RFdiffusion** | Protein structure generation via diffusion |
| **MolMIM** | Molecular generation and optimization |
| **DiffDock** | Molecular docking (protein-ligand binding) |

### Documentation
`https://docs.nvidia.com/nim/bionemo/latest/`

### Use Cases
- Drug candidate screening
- Protein engineering
- Molecular property prediction
- De novo molecule generation

## MONAI (Medical Imaging)

NIMs for medical image analysis built on the MONAI framework.

| Model | Description |
|---|---|
| **MAISI** | Medical AI for Synthetic Imaging |
| **VISTA-3D** | Volumetric medical image segmentation |

### Documentation
`https://docs.nvidia.com/nim/monai/latest/`

### Use Cases
- Medical image segmentation (CT, MRI)
- Synthetic medical data generation
- Radiology AI assistance

## Earth-2 (Climate & Weather)

NIMs for climate science and weather prediction.

| Model | Description |
|---|---|
| **CorrDiff** | Corrective diffusion for weather downscaling |
| **FourCastNet** | Global weather forecasting |

### Documentation
`https://docs.nvidia.com/nim/earth2/latest/`

### Use Cases
- High-resolution weather prediction
- Climate modeling and simulation
- Extreme weather event forecasting

## Simulation

| Model | Description |
|---|---|
| **DoMINO-Automotive-Aero** | Automotive aerodynamics simulation |

### Use Cases
- CFD (Computational Fluid Dynamics) surrogate modeling
- Automotive design optimization
- Real-time physics simulation
